# PyTorch 下的 QAT 教程

[![PyPI](https://img.shields.io/pypi/v/torch-quantization.svg)](https://pypi.org/project/torch-quantization/) [![GitHub issues](https://img.shields.io/github/issues/xinetzone/torch-quantization)](https://github.com/xinetzone/torch-quantization/issues) [![GitHub forks](https://img.shields.io/github/forks/xinetzone/torch-quantization)](https://github.com/xinetzone/torch-quantization/network) [![GitHub stars](https://img.shields.io/github/stars/xinetzone/torch-quantization)](https://github.com/xinetzone/torch-quantization/stargazers) [![GitHub license](https://img.shields.io/github/license/xinetzone/torch-quantization)](https://github.com/xinetzone/torch-quantization/blob/main/LICENSE) ![repo size](https://img.shields.io/github/repo-size/xinetzone/torch-quantization.svg) [![contributors](https://img.shields.io/github/contributors/xinetzone/torch-quantization.svg)](https://github.com/xinetzone/torch-quantization/graphs/contributors) [![watcher](https://img.shields.io/github/watchers/xinetzone/torch-quantization.svg)](https://github.com/xinetzone/torch-quantization/watchers) [![watcher](https://img.shields.io/github/watchers/xinetzone/pytorch-book.svg)](https://github.com/xinetzone/pytorch-book/watchers) [![Downloads](https://pepy.tech/badge/torch-quantization/week)](https://pepy.tech/project/torch-quantization)

## 支持 PyPI

需要安装 `torchq` 包：

```shell
pip install torchq
```
